@@ -82,11 +82,8 @@
  *
  * If you are using the theming layer standalone, you will need to set a
  * widget path and a screen yourself to the created style context through
- * gtk_style_context_set_path() and gtk_style_context_set_screen(), as well
- * as updating the context yourself using gtk_style_context_invalidate()
- * whenever any of the conditions change, such as a change in the
- * #GtkSettings:gtk-theme-name setting or a hierarchy change in the rendered
- * widget. See the “Foreign drawing“ example in gtk3-demo.
+ * gtk_style_context_set_path() and possibly gtk_style_context_set_screen(). See
+ * the “Foreign drawing“ example in gtk3-demo.
  *
  * # Style Classes # {#gtkstylecontext-classes}
  *
@@ -224,7 +221,7 @@ gtk_style_context_class_init (GtkStyleContextClass *klass)
                   G_SIGNAL_RUN_FIRST,
                   G_STRUCT_OFFSET (GtkStyleContextClass, changed),
                   NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
+                  NULL,
                   G_TYPE_NONE, 0);
 
   properties[PROP_SCREEN] =
@@ -1965,7 +1962,7 @@ gtk_style_context_lookup_icon_set (GtkStyleContext *context,
  * Attaches @context to the given screen.
  *
  * The screen is used to add style information from “global” style
- * providers, such as the screens #GtkSettings instance.
+ * providers, such as the screen’s #GtkSettings instance.
  *
  * If you are using a #GtkStyleContext returned from
  * gtk_widget_get_style_context(), you do not need to
